---
title: 중개플랫폼은 정산을 어떻게 해야할까요?
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
tags:
  - 정산
pgCompanies:
  - KSNET
  - 웰컴페이먼츠
  - 페이먼트월
  - 헥토파이낸셜
  - 키움페이
  - 토스페이먼츠
  - 스마트로
  - KICC
  - 나이스페이먼츠
  - NHN KCP
  - KG이니시스
searchTags:
  - 일괄정산
  - 지급대행
  - 포트원정산
  - 정산대행
  - 하위상점
  - 플랫폼
  - 중개
  - 중개서비스
datetime: 2024-03-18T09:39:46.726Z
---

<Callout content="중개플랫폼 이용시 이용하실 수 있는 결제대행사 정산대행 서비스 안내드립니다. 
포트원에서는 결제연동에 대한 부분만 지원되며 입점 기준 및 정산기준은 
결제대행사의 정책에 따라 적용되는 점 참고 부탁드립니다." />

### **중개 플랫폼이란?**

- **포트원에서 정의하는 온라인상 중개 플랫폼 사업자는 서비스를 공급하는 공급자와 서비스를 영위하는 소비자가 모이는 공간을 제공하는 사업자를 의미합니다.**

<Indent level="1">

1. 일반 사용자 (고객)
2. 플랫폼에 입점하여 서비스를 제공하는 사용자 (공급자)
3. 플랫폼 사업자 (플랫폼 서비스를 제공하는 사업자)

</Indent>

- 중개 플랫폼 형태의 경우 플랫폼 안에 공급자가 입점을 하기 때문에 결제뿐 아니라 추후 결제 대금의 정산 방법까지 고려하셔야 합니다.
- 정산처리를 결제대행사(PG사)<>입점몰(공급자) 로 받으실지, 결제대행사(PG사) <> 플랫폼 사업자로 받을지에 따라 계약절차가 상이할 수 있습니다.
- 또한 계약은 결제대행사의 입점 기준에 따라 심사 후 이용 가능하며 중개 플랫폼의 경우 입점 기준이 까다로울 수 있으므로 먼저 포트원을 통해 전자결제 신청하신 후 결제대행사와 상세한 입점 상담을 받아보시는 것을 추천드립니다.

<Callout title="포트원 전자결제 신청방법 보러가기 ↗" />

<Callout content="만약 결제대행사(PGP사) <> 하위상점(공급자) 간 직접 계약하시는 경우 결제대금 정산도 하위상점으로 직접 이루어집니다. 만약 플랫폼 서비스 이용비용을 받고자 하실 경우 별도로 수취해주셔야 합니다." title="참고사항" icon="💡" />

### **결제대행사(PG사)의 정산대행 부가서비스**

- 결제대행사(PG사) <> 플랫폼 사업자로 계약을 진행하시는 경우 정산 또한 플랫폼 사업자로 지급됩니다.
- 이 경우 플랫폼 사업자에서 하위 상점(공급자)로 정산처리를 직접 진행해 주셔야 하므로, 결제대행사의 정산 대행 부가서비스 고려하실 수 있습니다.
- 정산 대행 서비스는 결제대행사 자체적으로 제공되는 부가 서비스이므로, 원하시는 경우 이용하실 결제대행사를 통해 서비스 신청을 주시기 바랍니다.

<Callout title="결제대행사 정산대행 서비스 보러가기↗" />

### **포트원의 파트너 정산 자동화 서비스**

- 포트원 파트너 정산 자동화 서비스는 간단한 API 연동과 포트원의 관리자 콘솔을 통해서 간편하게 하위 정산을 처리하실 수 있도록 돕는 부가 서비스입니다. (유료)
- 파트너 정산 자동화 서비스와 관련하여 자세한 내용은 아래 가이드를 통해 확인하실 수 있습니다.

<Callout title="포트원 파트너 정산 자동화 보러가기 ↗" />
